raytraverse.sampler
==========================================================

draw
---------------------------

.. automodule:: raytraverse.sampler.draw
    :members:
    :undoc-members:
    :show-inheritance:

Sampler
---------------------------

.. autoclass:: raytraverse.sampler.Sampler
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SkySampler
--------------------------------

.. autoclass:: raytraverse.sampler.SkySampler
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunSampler
--------------------------------

.. autoclass:: raytraverse.sampler.SunSampler
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

SunViewSampler
------------------------------------

.. autoclass:: raytraverse.sampler.SunViewSampler
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

ImageSampler
--------------------------------

.. autoclass:: raytraverse.sampler.ImageSampler
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:

DeterministicImageSampler
--------------------------------

.. autoclass:: raytraverse.sampler.DeterministicImageSampler
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
